@@ -225,6 +225,18 @@ SUPPORTED_DEVICE_PARAMETERS = [
         tool_depth_min=0,
         tool_depth_max=10,
     ),
+    # Contributed by Yohalmo Garcia (@yohalmogarcia on GitHub, see issue #3)
+    DeviceParameters(
+        product_name='Silhouette Cameo4',
+        usb_vendor_id=0x0B4D,
+        usb_product_id=0x1137,
+        area_width_min=inch2mm(3.0),
+        area_width_max=inch2mm(12.0),
+        area_height_min=inch2mm(3.0),
+        area_height_max=inch2mm(40.0),
+        tool_depth_min=0,
+        tool_depth_max=10,
+    ),
 ]
 
 
